==> org.opennms.features.collection.api-20.0.0-20170207.154750-72-sources.jar: org/opennms/netmgt/collection/adapters/ResourceTypeMapper.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.adapters;

import java.util.function.Function;

import org.opennms.netmgt.collection.api.ResourceType;

/**
 * Singleton used to lookup {@link ResourceType}s by name.
 *
 * This class is used when unmarshaling generic resource
 * types (which currently only occurs in test code).
 *
 * This class will be removed once all of the {@link org.opennms.netmgt.collection.api.ServiceCollector}
 * implementations have been migrated to use the {@link org.opennms.netmgt.collection.support.builder.CollectionSetBuilder}.
 * At which point we'll be able to move the resource lookup and persistence logic outside the collectors and into collectd.
 *
 * @author jwhite
 */
public class ResourceTypeMapper {

    private static ResourceTypeMapper instance;

    private Function<String,ResourceType> mapper;

    private ResourceTypeMapper(){}

    public static ResourceTypeMapper getInstance(){
        if(instance == null){
            instance = new ResourceTypeMapper();
        }
        return instance;
    }

    public void setResourceTypeMapper(Function<String,ResourceType> mapper) {
        this.mapper = mapper;
    }

    public ResourceType getResourceType(String name) {
        if (mapper != null) {
            return mapper.apply(name);
        }
        return null;
    }
}

==> org.opennms.features.collection.api-20.0.0-20170304.071726-104-sources.jar: org/opennms/netmgt/collection/adapters/ResourceTypeMapper.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.adapters;

import java.util.function.Function;

import org.opennms.netmgt.collection.api.ResourceType;

/**
 * Singleton used to lookup {@link ResourceType}s by name.
 *
 * This class is used when resolving {@link org.opennms.netmgt.collection.support.builder.DeferredGenericTypeResource}
 * resource types.
 *
 * This class could be removed once all of the {@link org.opennms.netmgt.collection.api.ServiceCollector}
 * implementations have been migrated to use the {@link org.opennms.netmgt.collection.support.builder.CollectionSetBuilder}.
 * At which point we could move the resource lookup and persistence logic outside the collectors and into collectd.
 *
 * @author jwhite
 */
public class ResourceTypeMapper {

    private static ResourceTypeMapper instance;

    private Function<String,ResourceType> mapper;

    private ResourceTypeMapper(){}

    public static ResourceTypeMapper getInstance(){
        if(instance == null){
            instance = new ResourceTypeMapper();
        }
        return instance;
    }

    public void setResourceTypeMapper(Function<String,ResourceType> mapper) {
        this.mapper = mapper;
    }

    public ResourceType getResourceType(String name) {
        if (mapper != null) {
            return mapper.apply(name);
        }
        return null;
    }
}
